import random

def main():
	pracs = ['aerobic', 'sprints', 'technique', 'gym', 'mostly talk']
	prac = random.choice(pracs)
	print("Today's practice will be %s." % prac)
	if prac in ['aerobic', 'mostly talk']:
		print('Sorry...')
	else:
		print('Yes!')
	
	return(prac)

if __name__ == '__main__':
	main()



from setuptools import setup, find_packages

setup(
	name='pypck_dummy',
	version='0.0.10',
	description='This is a test.',
	author='',
	author_email='',
	url='https://gitub.com/...',
	packages=find_packages(),
	install_requires=[]
)



from .todays_practice import main

def practice_reaction().
	"""xxx"""

	prac = main()
	
	if prac in ["mostly talk", "aerobic"]:
		print("OOOOOH NOOOOOO!!")
	
	else:
		print(LET'S GOOOOOOOOOOO!!)


if __name__ == "__main__":
	practice_reaction()
